@@ -15,30 +15,30 @@ class SpreadsheetTest(unittest.TestCase):
 
     def setUp(self):
         test_file_path = os.path.join(TEST_FILES_IN, ALL_IN_FILES[1])
-        self.doc = openxmllib.openXmlDocument(test_file_path)
+        self.doc = openxmllib.openXmlDocument(path=test_file_path)
         return
 
 
     def test_indexableText(self):
-        """Indexable text with properties"""
-
-        itext = self.doc.indexableText()
+        """Indexable text with properties
+        """
+        itext = self.doc.indexableText().split()
         some_words = (u'this', u'is', u'a', u'spreadsheet', u'another', u'sum',
-            u'myinfo1', u'myinfo2', u'title', u'subject', u'comment', u'midword')
+            u'myinfo1', u'myinfo2', u'title', u'subject', u'comments', u'midword')
         for word in some_words:
-            self.failUnless(word in itext, "%s was expected" % word)
+            self.failUnless(word in itext, "%s was expected in %s" % (word, itext))
         return
 
 
     def test_indexableTextNoprop(self):
-        """Indexable text without properties"""
-
-        itext = self.doc.indexableText(include_properties=False)
+        """Indexable text without properties
+        """
+        itext = self.doc.indexableText(include_properties=False).split()
         some_words = (u'this', u'is', u'a', u'spreadsheet', u'another', u'sum')
         for word in some_words:
-            self.failUnless(word in itext, "%s was expected" % word)
+            self.failUnless(word in itext, "%s was expected in %s" % (word, itext))
         return
-# /class WordProcessingTest
+# /class SpreadsheetTest
 
 
 def test_suite():
